API docs for “spamfighter.rules.model.modelTrain”

# Class s.r.m.modelTrain(ModelRule):

Part of spamfighter.rules.model View Source View In Hierarchy

Обучить модель на сообщении: всегда истинно.

Method | analyze |

Inherited from ModelRule:

Method | __init__ | Конструктор.

def analyze(self, domain, message, marker='good', **kwargs): (source)
overrides spamfighter.rules.model.ModelRule.analyze

Parameters | marker | тип сообщения для модели, "good" или "bad" (type: `str` )